@@ -1,3 +1,4 @@
+from cbpi.api.dataclasses import Actor, Props
 from aiohttp import web
 from cbpi.api import *
 auth = False
@@ -22,6 +23,47 @@ class ActorHttpEndpoints():
                 description: successful operation
         """
         return web.json_response(data=self.controller.get_state())
+
+    @request_mapping(path="/ws_update", auth_required=False)
+    async def http_get_all(self, request):
+        """
+
+        ---
+        description: Update WS actors
+        tags:
+        - Actor
+        responses:
+            "204":
+                description: successful operation
+        """
+        return web.json_response(data=await self.controller.ws_actor_update())
+        
+
+    @request_mapping(path="/{id:\w+}", auth_required=False)
+    async def http_get_one(self, request):
+        """
+        ---
+        description: Get one Actor
+        tags:
+        - Actor
+        parameters:
+        - name: "id"
+          in: "path"
+          description: "Actor ID"
+          required: true
+          type: "integer"
+          format: "int64"
+        responses:
+            "200":
+                description: successful operation
+            "404":
+                description: Actor not found
+        """
+        actor = self.controller.find_by_id(request.match_info['id'])
+        if (actor is None):
+          return web.json_response(status=404)
+
+        return web.json_response(data=actor.to_dict(), status=200)
         
 
     @request_mapping(path="/", method="POST", auth_required=False)
@@ -57,9 +99,10 @@ class ActorHttpEndpoints():
                 description: successful operation
         """
         data = await request.json()
-        response_data = await self.controller.add(data)
+        actor = Actor(name=data.get("name"), props=Props(data.get("props", {})), type=data.get("type"))
+        response_data = await self.controller.add(actor)
 
-        return web.json_response(data=self.controller.create_dict(response_data))
+        return web.json_response(data=response_data.to_dict())
         
 
     @request_mapping(path="/{id}", method="PUT", auth_required=False)
@@ -95,7 +138,8 @@ class ActorHttpEndpoints():
         """
         id = request.match_info['id']
         data = await request.json()
-        return web.json_response(data=self.controller.create_dict(await self.controller.update(id, data)))
+        actor = Actor(id=id, name=data.get("name"), props=Props(data.get("props", {})), type=data.get("type"))
+        return web.json_response(data=(await self.controller.update(actor)).to_dict())
     
     @request_mapping(path="/{id}", method="DELETE", auth_required=False)
     async def http_delete_one(self, request):
@@ -203,6 +247,7 @@ class ActorHttpEndpoints():
         """
         actor_id = request.match_info['id']
         data = await request.json()
-        await self.controller.call_action(actor_id, data.get("name"), data.get("parameter"))
+        print(data)
+        await self.controller.call_action(actor_id, data.get("action"), data.get("parameter"))
 
         return web.Response(status=204)
\ No newline at end of file
